@@ -52,8 +52,8 @@ impl Calculator for Network {
                 (net_parts >> 40 & 0xffff) as u16,
                 (net_parts >> 24 & 0xffff) as u16,
                 (net_parts >> 8 & 0xffff) as u16,
-                (((net_parts & 0xff) as u16) << 8) | 0x99 as u16,
-                0x9300 as u16,
+                (((net_parts & 0xff) as u16) << 8) | 0x99,
+                0x9300,
                 0,
                 0,
             )),
@@ -92,7 +92,7 @@ impl Calculator for Member {
                 (net_parts >> 40 & 0xffff) as u16,
                 (net_parts >> 24 & 0xffff) as u16,
                 (net_parts >> 8 & 0xffff) as u16,
-                (((net_parts & 0xff) as u16) << 8) | 0x99 as u16,
+                (((net_parts & 0xff) as u16) << 8) | 0x99,
                 0x9300 | (node_parts >> 32 & 0xff) as u16,
                 (node_parts >> 16 & 0xffff) as u16,
                 (node_parts & 0xffff) as u16,
